@@ -7,7 +7,7 @@ This test suite checks the methods of the Movies class of tmdbsimple.
 
 Created by Celia Oakley on 2013-11-05
 
-:copyright: (c) 2013-2020 by Celia Oakley.
+:copyright: (c) 2013-2022 by Celia Oakley.
 :license: GPLv3, see LICENSE for more details.
 """
 
@@ -22,13 +22,13 @@ Constants
 """
 MOVIE_ID = 103332
 MOVIE_TITLE = 'Ruby Sparks'
-MOVIE_TITLE_FRENCH = "Elle s'appelle Ruby"
+MOVIE_TITLE_GERMAN = 'Ruby Sparks - Meine fabelhafte Freundin'
 MOVIE_ID_ALTERNATIVE = 550
 RATING = 7.5
 COLLECTION_ID = 10
 COLLECTION_NAME = 'Star Wars Collection'
 COMPANY_ID = 1
-COMPANY_NAME = 'Lucasfilm Ltd.'
+COMPANY_NAME = 'Lucasfilm'
 KEYWORD_ID = 1721
 KEYWORD_NAME = 'fight'
 REVIEW_ID = '5013bc76760ee372cb00253e'
@@ -52,9 +52,9 @@ class MoviesTestCase(unittest.TestCase):
 
     def test_movies_info_with_params(self):
         id = MOVIE_ID
-        title = MOVIE_TITLE_FRENCH
+        title = MOVIE_TITLE_GERMAN
         movie = tmdb.Movies(id)
-        movie.info(language='fr')
+        movie.info(language='de')
         self.assertEqual(movie.title, title)
 
     def test_movies_account_states(self):
@@ -99,34 +99,22 @@ class MoviesTestCase(unittest.TestCase):
         movie.keywords()
         self.assertTrue(hasattr(movie, 'keywords'))
 
-    def test_movies_release_dates(self):
+    def test_movies_lists(self):
         id = MOVIE_ID
         movie = tmdb.Movies(id)
-        movie.release_dates()
+        movie.lists()
         self.assertTrue(hasattr(movie, 'results'))
 
-    def test_movies_videos(self):
-        id = MOVIE_ID
-        movie = tmdb.Movies(id)
-        movie.videos()
-        self.assertTrue(hasattr(movie, 'results'))
-
-    def test_movies_translations(self):
-        id = MOVIE_ID_ALTERNATIVE
-        movie = tmdb.Movies(id)
-        movie.translations()
-        self.assertTrue(hasattr(movie, 'translations'))
-
     def test_movies_recommendations(self):
         id = MOVIE_ID
         movie = tmdb.Movies(id)
         movie.recommendations()
         self.assertTrue(hasattr(movie, 'results'))
 
-    def test_movies_similar_movies(self):
-        id = MOVIE_ID_ALTERNATIVE
+    def test_movies_release_dates(self):
+        id = MOVIE_ID
         movie = tmdb.Movies(id)
-        movie.similar_movies()
+        movie.release_dates()
         self.assertTrue(hasattr(movie, 'results'))
 
     def test_movies_reviews(self):
@@ -135,10 +123,28 @@ class MoviesTestCase(unittest.TestCase):
         movie.reviews()
         self.assertTrue(hasattr(movie, 'results'))
 
-    def test_movies_lists(self):
+    def test_movies_similar_movies(self):
+        id = MOVIE_ID_ALTERNATIVE
+        movie = tmdb.Movies(id)
+        movie.similar_movies()
+        self.assertTrue(hasattr(movie, 'results'))
+
+    def test_movies_translations(self):
+        id = MOVIE_ID_ALTERNATIVE
+        movie = tmdb.Movies(id)
+        movie.translations()
+        self.assertTrue(hasattr(movie, 'translations'))
+
+    def test_movies_videos(self):
         id = MOVIE_ID
         movie = tmdb.Movies(id)
-        movie.lists()
+        movie.videos()
+        self.assertTrue(hasattr(movie, 'results'))
+
+    def test_movies_watch_providers(self):
+        id = MOVIE_ID
+        movie = tmdb.Movies(id)
+        movie.watch_providers()
         self.assertTrue(hasattr(movie, 'results'))
 
     def test_movies_rating_and_rating_delete(self):
