@@ -8,7 +8,7 @@ This test suite checks the methods of the Test class of tmdbsimple.
 
 Created by Celia Oakley on 2013-11-05
 
-:copyright: (c) 2013-2020 by Celia Oakley.
+:copyright: (c) 2013-2022 by Celia Oakley.
 :license: GPLv3, see LICENSE for more details.
 """
 
@@ -139,6 +139,12 @@ class TVTestCase(unittest.TestCase):
         tv.videos()
         self.assertTrue(hasattr(tv, 'results'))
 
+    def test_tv_watch_providers(self):
+        id = TV_ID
+        tv = tmdb.TV(id)
+        tv.watch_providers()
+        self.assertTrue(hasattr(tv, 'results'))
+
     def test_tv_rating_and_rating_delete(self):
         status_code_create = SUCCESSFUL_CREATE
         status_code_update = SUCCESSFUL_UPDATE
